==> jc-1.4.0.tar.gz: java/nio/MappedByteBuffer.h <==
// public abstract class java.nio.MappedByteBuffer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9a9842bb79e9de6a java_nio_Buffer
// @dep_class c56860d6af73feea java_nio_ByteBuffer
// @dep_class 3e64e8b642c1cee6 java_nio_MappedByteBuffer

// header file dependencies
// @dep_header java_nio_ByteBuffer

#include "java/nio/ByteBuffer.h"

#ifndef _JC_java_nio_MappedByteBuffer_H_
#define _JC_java_nio_MappedByteBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_MappedByteBuffer$object;

// Typedefs
typedef struct _jc_java_nio_MappedByteBuffer$sub_refs	_jc_java_nio_MappedByteBuffer$sub_refs;
typedef struct _jc_java_nio_MappedByteBuffer$sub_nonrefs	_jc_java_nio_MappedByteBuffer$sub_nonrefs;
typedef struct _jc_java_nio_MappedByteBuffer$refs	_jc_java_nio_MappedByteBuffer$refs;
typedef struct _jc_java_nio_MappedByteBuffer$nonrefs	_jc_java_nio_MappedByteBuffer$nonrefs;
typedef struct _jc_java_nio_MappedByteBuffer$object	_jc_java_nio_MappedByteBuffer$object;

typedef const struct _jc_java_nio_MappedByteBuffer$vmethods	_jc_java_nio_MappedByteBuffer$vmethods;
typedef const struct _jc_java_nio_MappedByteBuffer$vtable	_jc_java_nio_MappedByteBuffer$vtable;
typedef const struct _jc_java_nio_MappedByteBuffer$vtype	_jc_java_nio_MappedByteBuffer$vtype;

// Constructors
extern void _jc_java_nio_MappedByteBuffer$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *, jint, jint, jint, jint);

// Virtual methods
extern void _jc_java_nio_MappedByteBuffer$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
extern struct _jc_java_nio_MappedByteBuffer$object *_jc_java_nio_MappedByteBuffer$method$force$e939ed27d0e699de(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
extern void _jc_java_nio_MappedByteBuffer$method$forceImpl$f1bf45cb82b36f8f(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
extern jboolean _jc_java_nio_MappedByteBuffer$method$isLoaded$c05be592a58cd42a(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
extern jboolean _jc_java_nio_MappedByteBuffer$method$isLoadedImpl$f7263521437b84fc(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
extern struct _jc_java_nio_MappedByteBuffer$object *_jc_java_nio_MappedByteBuffer$method$load$660263645d071916(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
extern void _jc_java_nio_MappedByteBuffer$method$loadImpl$71d11b397ee1b42d(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
extern void _jc_java_nio_MappedByteBuffer$method$unmapImpl$d004c500b6126964(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$force$e939ed27d0e699de;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$forceImpl$f1bf45cb82b36f8f;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$isLoaded$c05be592a58cd42a;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$isLoadedImpl$f7263521437b84fc;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$load$660263645d071916;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$loadImpl$71d11b397ee1b42d;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$unmapImpl$d004c500b6126964;

// Virtual methods structure
struct _jc_java_nio_MappedByteBuffer$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
	struct _jc_java_nio_MappedByteBuffer$object	*(*force$e939ed27d0e699de)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
	void	(*forceImpl$f1bf45cb82b36f8f)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
	jboolean	(*isLoaded$c05be592a58cd42a)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
	jboolean	(*isLoadedImpl$f7263521437b84fc)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
	struct _jc_java_nio_MappedByteBuffer$object	*(*load$660263645d071916)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
	void	(*loadImpl$71d11b397ee1b42d)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
	void	(*unmapImpl$d004c500b6126964)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *);
};

// Vtable
struct _jc_java_nio_MappedByteBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_Buffer$vmethods	java_nio_Buffer;
	_jc_java_nio_ByteBuffer$vmethods	java_nio_ByteBuffer;
	_jc_java_nio_MappedByteBuffer$vmethods	java_nio_MappedByteBuffer;
};

// Vtype
struct _jc_java_nio_MappedByteBuffer$vtype {
	_jc_type			type;
	_jc_java_nio_MappedByteBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_MappedByteBuffer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_MappedByteBuffer$refs {
    _jc_java_nio_MappedByteBuffer$sub_refs	java_nio_MappedByteBuffer;
    _jc_java_nio_ByteBuffer$sub_refs	java_nio_ByteBuffer;
    _jc_java_nio_Buffer$sub_refs	java_nio_Buffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_MappedByteBuffer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_MappedByteBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_Buffer$sub_nonrefs	java_nio_Buffer;
    _jc_java_nio_ByteBuffer$sub_nonrefs	java_nio_ByteBuffer;
    _jc_java_nio_MappedByteBuffer$sub_nonrefs	java_nio_MappedByteBuffer;
};

// Object instance structure
struct _jc_java_nio_MappedByteBuffer$object {
	_jc_java_nio_MappedByteBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_MappedByteBuffer$vtype	*vtype;
	_jc_java_nio_MappedByteBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_MappedByteBuffer$vtype _jc_java_nio_MappedByteBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_MappedByteBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_MappedByteBuffer$class_object;

#endif	/* _JC_java_nio_MappedByteBuffer_H_ */

==> jc-1.4.6.tar.gz: java/nio/MappedByteBuffer.h <==
// public abstract class java.nio.MappedByteBuffer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9a9842bb79e9de6a java_nio_Buffer
// @dep_class c56860d6af73feea java_nio_ByteBuffer
// @dep_class 3e64e8b642c1cee6 java_nio_MappedByteBuffer

// header file dependencies
// @dep_header java_nio_ByteBuffer

#include "java/nio/ByteBuffer.h"

#ifndef _JC_java_nio_MappedByteBuffer_H_
#define _JC_java_nio_MappedByteBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_MappedByteBuffer$object;

// Typedefs
typedef struct _jc_java_nio_MappedByteBuffer$sub_refs	_jc_java_nio_MappedByteBuffer$sub_refs;
typedef struct _jc_java_nio_MappedByteBuffer$sub_nonrefs	_jc_java_nio_MappedByteBuffer$sub_nonrefs;
typedef struct _jc_java_nio_MappedByteBuffer$refs	_jc_java_nio_MappedByteBuffer$refs;
typedef struct _jc_java_nio_MappedByteBuffer$nonrefs	_jc_java_nio_MappedByteBuffer$nonrefs;
typedef struct _jc_java_nio_MappedByteBuffer$object	_jc_java_nio_MappedByteBuffer$object;

typedef const struct _jc_java_nio_MappedByteBuffer$vmethods	_jc_java_nio_MappedByteBuffer$vmethods;
typedef const struct _jc_java_nio_MappedByteBuffer$vtable	_jc_java_nio_MappedByteBuffer$vtable;
typedef const struct _jc_java_nio_MappedByteBuffer$vtype	_jc_java_nio_MappedByteBuffer$vtype;

// Constructors
extern void _jc_java_nio_MappedByteBuffer$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_nio_MappedByteBuffer$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_MappedByteBuffer$object *_jc_java_nio_MappedByteBuffer$method$force$e939ed27d0e699de(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
extern void _jc_java_nio_MappedByteBuffer$method$forceImpl$f1bf45cb82b36f8f(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_nio_MappedByteBuffer$method$isLoaded$c05be592a58cd42a(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_nio_MappedByteBuffer$method$isLoadedImpl$f7263521437b84fc(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_MappedByteBuffer$object *_jc_java_nio_MappedByteBuffer$method$load$660263645d071916(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
extern void _jc_java_nio_MappedByteBuffer$method$loadImpl$71d11b397ee1b42d(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
extern void _jc_java_nio_MappedByteBuffer$method$unmapImpl$d004c500b6126964(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$force$e939ed27d0e699de;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$forceImpl$f1bf45cb82b36f8f;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$isLoaded$c05be592a58cd42a;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$isLoadedImpl$f7263521437b84fc;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$load$660263645d071916;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$loadImpl$71d11b397ee1b42d;
extern _jc_method _jc_java_nio_MappedByteBuffer$method_info$unmapImpl$d004c500b6126964;

// Virtual methods structure
struct _jc_java_nio_MappedByteBuffer$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_MappedByteBuffer$object	*(*force$e939ed27d0e699de)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
	void	(*forceImpl$f1bf45cb82b36f8f)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*isLoaded$c05be592a58cd42a)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*isLoadedImpl$f7263521437b84fc)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_MappedByteBuffer$object	*(*load$660263645d071916)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
	void	(*loadImpl$71d11b397ee1b42d)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
	void	(*unmapImpl$d004c500b6126964)(_jc_env *, struct _jc_java_nio_MappedByteBuffer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_MappedByteBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_Buffer$vmethods	java_nio_Buffer;
	_jc_java_nio_ByteBuffer$vmethods	java_nio_ByteBuffer;
	_jc_java_nio_MappedByteBuffer$vmethods	java_nio_MappedByteBuffer;
};

// Vtype
struct _jc_java_nio_MappedByteBuffer$vtype {
	_jc_type			type;
	_jc_java_nio_MappedByteBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_MappedByteBuffer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_MappedByteBuffer$refs {
    _jc_java_nio_MappedByteBuffer$sub_refs	java_nio_MappedByteBuffer;
    _jc_java_nio_ByteBuffer$sub_refs	java_nio_ByteBuffer;
    _jc_java_nio_Buffer$sub_refs	java_nio_Buffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_MappedByteBuffer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_MappedByteBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_Buffer$sub_nonrefs	java_nio_Buffer;
    _jc_java_nio_ByteBuffer$sub_nonrefs	java_nio_ByteBuffer;
    _jc_java_nio_MappedByteBuffer$sub_nonrefs	java_nio_MappedByteBuffer;
};

// Object instance structure
struct _jc_java_nio_MappedByteBuffer$object {
	_jc_java_nio_MappedByteBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_MappedByteBuffer$vtype	*vtype;
	_jc_java_nio_MappedByteBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_MappedByteBuffer$vtype _jc_java_nio_MappedByteBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_MappedByteBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_MappedByteBuffer$class_object;

#endif	/* _JC_java_nio_MappedByteBuffer_H_ */
